AxiLiteBenchmarkControl

Struct AxiLiteBenchmarkControl 

pub struct AxiLiteBenchmarkControl {
Show 19 fields pub aw_pending: bool, pub aw_addr: b12, pub aw_locked_at_accept: bool, pub w_pending: bool, pub w_data: b32, pub w_strb: b4, pub w_locked_at_accept: bool, pub b_valid: bool, pub b_resp: b2, pub r_valid: bool, pub r_data: b32, pub r_resp: b2, pub start_pending: bool, pub done: bool, pub gie: bool, pub ier: b2, pub isr: b2, pub fault_seen: bool, pub last_reject_code: b8,
}
Resettable AXI channel ownership and interrupt state.

Fields

aw_pending: bool

One write address is buffered.

aw_addr: b12

Buffered write address.

aw_locked_at_accept: bool

Engine/configuration lock state sampled when AW transferred.

w_pending: bool

One write data beat is buffered.

w_data: b32

Buffered write data.

w_strb: b4

Buffered byte strobes.

w_locked_at_accept: bool

Engine/configuration lock state sampled when W transferred.

b_valid: bool

Registered write response is owned by the B channel.

b_resp: b2

Registered write response.

r_valid: bool

Registered read response is owned by the R channel.

r_data: b32

Registered read data.

r_resp: b2

Registered read response.

start_pending: bool

AP_START is waiting for engine acceptance/rejection.

done: bool

Sticky AP_DONE, clear on AP_CTRL read.

gie: bool

Global interrupt enable.

ier: b2

Done/fault interrupt enables.

isr: b2

Done/fault sticky interrupt status.

fault_seen: bool

Prevent repeated fault-event assertion after software clears ISR.

last_reject_code: b8

Most recent invalid-launch reason.