pub struct LaneLocalClusterOutput {Show 19 fields
pub start_ready: bool,
pub start_accepted: bool,
pub start_context: b2,
pub start_generation: b8,
pub context_active: [bool; 4],
pub context_credit_reserved: [bool; 4],
pub context_result_valid: [bool; 4],
pub context_fault: [bool; 4],
pub request_accepted: [bool; 4],
pub lane_response_rejected: bool,
pub discarded: [bool; 4],
pub error_valid: bool,
pub error_job_id: b32,
pub error_context: b2,
pub error_credit_release: bool,
pub output_valid: bool,
pub output: LaneLocalBeat,
pub output_credit_release: bool,
pub fault: bool,
}Expand description
Observable status and registered stream output from one local cluster.
Fields
start_ready: boolAt least one context can accept the offered start.
start_accepted: boolA start transferred in this cycle.
start_context: b2Local context selected for the offered start.
start_generation: b8Generation assigned to the offered start.
context_active: [bool; 4]Contexts currently traversing their task DAG.
context_credit_reserved: [bool; 4]Contexts owning active or retained output credit.
context_result_valid: [bool; 4]Contexts currently retaining complete results.
context_fault: [bool; 4]Context sticky fault indicators.
request_accepted: [bool; 4]Per-context request acceptance pulses.
lane_response_rejected: boolA lane response was rejected before routing.
discarded: [bool; 4]Faulted retained results discarded in this cycle.
error_valid: boolA held faulted-job completion is available.
error_job_id: b32Opaque identity of the held faulted-job completion.
error_context: b2Local context owning the held faulted-job completion.
error_credit_release: boolError completion transferred and released its context this cycle.
output_valid: boolA registered stream beat is available.
output: LaneLocalBeatRegistered stream beat, stable under backpressure.
output_credit_release: boolFinal beat transferred and released its context this cycle.
fault: boolSticky cluster integrity or framing fault.