pub fn issue_control_kernel(
input: IssueControlInput,
cursor: b4,
) -> IssueControlOutputExpand description
Fairly select at most three distinct canonical context tags.
This is the area-small control kernel used by the complete payload fabric and by emitted-Verilog tests.