pub fn legacy_hash32_state_kernel(value: LegacyHashLanes) -> KeccakStateExpand description
Build the single padded rate state for a 32-byte legacy Keccak hash.
pub fn legacy_hash32_state_kernel(value: LegacyHashLanes) -> KeccakStateBuild the single padded rate state for a 32-byte legacy Keccak hash.