pub fn decode_hardware_counts_kernel(counts: b88) -> HardwareTaskCountsExpand description
Unpack the scalar counter register into its eight audit classes.
pub fn decode_hardware_counts_kernel(counts: b88) -> HardwareTaskCountsUnpack the scalar counter register into its eight audit classes.