pub fn select_global_lane_kernel(
eligible: [bool; 3],
cursor: b2,
) -> GlobalLaneSelectionExpand description
Select one of three eligible clusters with rotating fairness.
pub fn select_global_lane_kernel(
eligible: [bool; 3],
cursor: b2,
) -> GlobalLaneSelectionSelect one of three eligible clusters with rotating fairness.