pub fn select_verify_cluster_context_kernel(
eligible: [bool; 4],
cursor: b2,
) -> VerifyClusterSelectionExpand description
Select one of four eligible contexts with rotating fairness.
pub fn select_verify_cluster_context_kernel(
eligible: [bool; 4],
cursor: b2,
) -> VerifyClusterSelectionSelect one of four eligible contexts with rotating fairness.