verification_chain_fields_kernel

Function verification_chain_fields_kernel 

pub fn verification_chain_fields_kernel(
    stage: b5,
    segment: b7,
    context: b4,
    generation: b8,
) -> TagFields
Build the one canonical chain tag named by a verifier segment stage.

Stages 3 through 17 name chain steps 1 through 15. Callers never invoke this kernel for the endpoint sentinel stage 18.